<?php

namespace FiloBlu\CegidY2\Service;

use Magento\Framework\ObjectManagerInterface;
use WsdlToPhp\PackageBase\AbstractSoapClientBase;

/**
 * Class ServiceFactory
 * @package FiloBlu\CegidY2Api\Service
 */
class ServiceProvider {

    /**
     * @var ObjectManagerInterface
     */
    protected $objectManager;
    /**
     * @var CredentialProvider
     */
    protected $credentialProvider;
    /**
     * @var string
     */
    protected $instanceName;
    /**
     * @var string
     */
    protected $serviceId;
    /**
     * @var array
     */
    protected $wsdlOptions;
    /**
     * @var string
     */
    protected $wsdlClassMap;

    /**
     * ServiceFactory constructor.
     * @param ObjectManagerInterface $objectManager
     * @param CredentialProvider $credentialProvider
     * @param string $instanceName
     * @param string $wsdlClassMap
     * @param string $serviceId
     * @param array $wsdlOptions
     */
    public function __construct(ObjectManagerInterface $objectManager, CredentialProvider $credentialProvider, $instanceName , $wsdlClassMap, $serviceId, $wsdlOptions = []) {
        $this->objectManager = $objectManager;
        $this->credentialProvider = $credentialProvider;
        $this->instanceName = $instanceName;
        $this->wsdlOptions = $wsdlOptions;
        $this->serviceId = $serviceId;
        $this->wsdlClassMap = $wsdlClassMap;
    }

    /**
     * @param array $data
     * @return mixed
     */
    public function create(array $data = [])
    {
        $data['wsdlOptions'] = $this->credentialProvider->getCredentials($this->serviceId);
        $data['wsdlOptions'][ AbstractSoapClientBase::WSDL_CLASSMAP ] = $this->objectManager->get($this->wsdlClassMap)->get();
        return $this->objectManager->create($this->instanceName, $data);
    }
}